==> scraperfc-3.0.0.tar.gz: scraperfc-3.0.0/README.md <==
<p align="center">
  <img src="https://github.com/oseymour/ScraperFC/blob/main/docs/source/images/ScraperFC-Logo-Final-2023-10-11 copy-Full-Color.svg?raw=true" alt="ScraperFC logo. The text 'ScraperFC' with some lines, X's, and O's around it. Meant to look similar to a tactics board or diagram.">
</p>
<p align="center">
  <a href="https://pypi.org/project/ScraperFC/">
    <img src="https://img.shields.io/pypi/v/scraperfc.svg", alt="pypi version badge">
  </a>
 <a href="https://scraperfc.readthedocs.io/en/latest/">
    <img src="https://readthedocs.org/projects/nrc4d/badge/?version=latest" alt="documentation status badge"/>
  </a>
  <a href="https://pypi.org/project/ScraperFC/">
    <img src="https://img.shields.io/pypi/dm/ScraperFC.svg" alt="monthly pypi downloads badge"/>
  </a>
</p>
<p align="center">
  <a href=https://discord.com/invite/C5N8dqCJAq>
    <img src="https://dcbadge.limes.pink/api/server/C5N8dqCJAq" alt="Discord invite link badge">
  </a>
  <a href="https://buymeacoffee.com/oseymour">
    <img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me A Coffee badge">
  </a>
</p>

This is ScraperFC, a Python package that I hope will give more people access to soccer data. Gone are the days of downloading spreadsheets one-by-one, copy-pasting, or entering data by hand. I try to make ScraperFC as easy-to-use as possible so that anybody with a bit of Python experience can use it.

To install ScraperFC, run ```pip install ScraperFC``` from the command line.

Data can be scraped from the following sources:
* [Capology](https://www.capology.com/)
* [ClubELO](http://clubelo.com/)
* [FBref](https://fbref.com/en/)
* [FiveThirtyEight](https://projects.fivethirtyeight.com/soccer-predictions/)
* [SofaScore](https://www.sofascore.com/)
* [Transfermarkt](https://www.transfermarkt.us/)
* [Understat](https://understat.com/)

For documentation, head over to the [Read the Docs page](https://scraperfc.readthedocs.io).

For usage examples, look at Examples.ipynb in the top level directory or some of my example analyses in the analytics_examples folder.

Join our [Discord](https://discord.gg/C5N8dqCJAq)!

I'd love to hear your feedback, bugs you find, or new features you want! The best way is to open an issue on this repository and I can respond to it there. Otherwise, you can reach me via email at osmour043@gmail.com or my Twitter handle is [@owen_seymour](https://twitter.com/owen_seymour).

==> scraperfc-3.1.0.tar.gz: scraperfc-3.1.0/README.md <==
<p align="center">
  <img src="https://github.com/oseymour/ScraperFC/blob/main/docs/source/images/ScraperFC-Logo-Final-2023-10-11 copy-Full-Color.svg?raw=true" alt="ScraperFC logo. The text 'ScraperFC' with some lines, X's, and O's around it. Meant to look similar to a tactics board or diagram."></img>
</p>
<p align="center">
  <a href="https://pypi.org/project/ScraperFC/">
    <img src="https://img.shields.io/pypi/v/scraperfc.svg", alt="pypi version badge"></img>
  </a>
  <a href="https://scraperfc.readthedocs.io/en/latest/">
    <img src="https://readthedocs.org/projects/nrc4d/badge/?version=latest" alt="documentation status badge"/></img>
  </a>
  <a href="https://pypi.org/project/ScraperFC/">
    <img src="https://img.shields.io/pypi/dm/ScraperFC.svg" alt="monthly pypi downloads badge"/></img>
  </a>
</p>
<p align="center">
  <a href=https://discord.com/invite/C5N8dqCJAq>
    <img src="https://dcbadge.limes.pink/api/server/C5N8dqCJAq" alt="Discord invite link badge"></img>
  </a>
  <a href="https://buymeacoffee.com/oseymour">
    <img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me A Coffee badge"></img>
  </a>
</p>

This is ScraperFC, a Python package that I hope will give more people access to soccer data. Gone are the days of downloading spreadsheets one-by-one, copy-pasting, or entering data by hand. I try to make ScraperFC as easy-to-use as possible so that anybody with a bit of Python experience can use it.

To install ScraperFC, run ```pip install ScraperFC``` from the command line.

Data can be scraped from the following sources:
* [Capology](https://www.capology.com/)
* [ClubELO](http://clubelo.com/)
* [FBref](https://fbref.com/en/)
* [FiveThirtyEight](https://projects.fivethirtyeight.com/soccer-predictions/)
* [SofaScore](https://www.sofascore.com/)
* [Transfermarkt](https://www.transfermarkt.us/)
* [Understat](https://understat.com/)

For documentation, head over to the [Read the Docs page](https://scraperfc.readthedocs.io).

Join our [Discord](https://discord.gg/C5N8dqCJAq)!

I'd love to hear your feedback, bugs you find, or new features you want! The best way is to open an issue on this repository and I can respond to it there. Otherwise, you can reach me via email at osmour043@gmail.com or my Twitter handle is [@owen_seymour](https://twitter.com/owen_seymour).
